#[non_exhaustive]pub struct SubfieldPatternQuery {
pub tag: String,
pub subfield_code: char,
pub negate: bool,
/* private fields */
}Expand description
Query for fields with subfield values matching a regex pattern.
This enables finding fields where a specific subfield’s value matches a regular expression pattern.
Examples
ⓘ
// Find all ISBNs that start with 978
let query = SubfieldPatternQuery::new("020", 'a', "^978-.*");
for field in record.fields_matching_pattern(&query) {
println!("ISBN: {:?}", field);
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tag: StringTag to match
subfield_code: charSubfield code to match
negate: boolIf true, match fields where the subfield does NOT match the pattern
Implementations
Sourceimpl SubfieldPatternQuery
impl SubfieldPatternQuery
Sourcepub fn new(
tag: impl Into<String>,
subfield_code: char,
pattern: &str,
) -> Result<Self, Error>
pub fn new( tag: impl Into<String>, subfield_code: char, pattern: &str, ) -> Result<Self, Error>
Create a new subfield pattern query.
Arguments
tag- The field tag to search insubfield_code- The subfield code to match againstpattern- A regex pattern string
Returns
Ok(SubfieldPatternQuery) if the pattern is valid regex, or Err if invalid.
Errors
Returns a regex::Error if the pattern is not a valid regular expression.
Examples
ⓘ
let query = SubfieldPatternQuery::new("650", 'a', r"^[A-Z]")?;Sourcepub fn negated(
tag: impl Into<String>,
subfield_code: char,
pattern: &str,
) -> Result<Self, Error>
pub fn negated( tag: impl Into<String>, subfield_code: char, pattern: &str, ) -> Result<Self, Error>
Create a negated subfield pattern query.
Matches fields where the subfield exists but does NOT match the pattern.
Errors
Returns a regex::Error if the pattern is not a valid regular expression.