pub struct SubfieldPatternQuery {
pub tag: String,
pub subfield_code: char,
/* private fields */
}Expand description
Query for fields with subfield values matching a regex pattern.
This enables finding fields where a specific subfield’s value matches a regular expression pattern.
Examples
ⓘ
// Find all ISBNs that start with 978
let query = SubfieldPatternQuery::new("020", 'a', "^978-.*");
for field in record.fields_matching_pattern(&query) {
println!("ISBN: {:?}", field);
}Fields
tag: StringTag to match
subfield_code: charSubfield code to match
Implementations
Sourceimpl SubfieldPatternQuery
impl SubfieldPatternQuery
Sourcepub fn new(
tag: impl Into<String>,
subfield_code: char,
pattern: &str,
) -> Result<Self, Error>
pub fn new( tag: impl Into<String>, subfield_code: char, pattern: &str, ) -> Result<Self, Error>
Create a new subfield pattern query.
Arguments
tag- The field tag to search insubfield_code- The subfield code to match againstpattern- A regex pattern string
Returns
Ok(SubfieldPatternQuery) if the pattern is valid regex, or Err if invalid.
Errors
Returns a regex::Error if the pattern is not a valid regular expression.
Examples
ⓘ
let query = SubfieldPatternQuery::new("650", 'a', r"^[A-Z]")?;Trait Implementations
Sourceimpl Clone for SubfieldPatternQuery
impl Clone for SubfieldPatternQuery
Sourcefn clone(&self) -> SubfieldPatternQuery
fn clone(&self) -> SubfieldPatternQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SubfieldPatternQuery
impl RefUnwindSafe for SubfieldPatternQuery
impl Send for SubfieldPatternQuery
impl Sync for SubfieldPatternQuery
impl Unpin for SubfieldPatternQuery
impl UnsafeUnpin for SubfieldPatternQuery
impl UnwindSafe for SubfieldPatternQuery