Module validation

Module validation 

Indicator and field validation for MARC records.

This module provides validation of MARC field indicators according to MARC21 standards. Indicators are the two characters following a field tag that specify how the field should be interpreted.

Structs

IndicatorMeaning
Semantic meaning of an indicator value for a specific field
IndicatorRules
Validation rules for a field’s indicators
IndicatorValidator
Validator for MARC field indicators

Enums

IndicatorValidation
Validation rule for a single indicator