Indicator and field validation for MARC records.
This module provides validation of MARC field indicators according to MARC21 standards. Indicators are the two characters following a field tag that specify how the field should be interpreted.
Structs
- Indicator
Meaning - Semantic meaning of an indicator value for a specific field
- Indicator
Rules - Validation rules for a field’s indicators
- Indicator
Validator - Validator for MARC field indicators
Enums
- Indicator
Validation - Validation rule for a single indicator